@@ -92,7 +92,7 @@ func NewServiceDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			client, err := p.NewClient(namespace)
+			client, err := p.NewServingClient(namespace)
 			if err != nil {
 				return err
 			}
@@ -162,9 +162,11 @@ func describe(w io.Writer, service *v1alpha1.Service, revisions []*revisionDesc,
 func writeService(dw printers.PrefixWriter, service *v1alpha1.Service) {
 	commands.WriteMetadata(dw, &service.ObjectMeta, printDetails)
 	dw.WriteAttribute("URL", extractURL(service))
-	if service.Status.Address != nil {
-		url := service.Status.Address.GetURL()
-		dw.WriteAttribute("Cluster", url.String())
+	if printDetails {
+		if service.Status.Address != nil {
+			url := service.Status.Address.GetURL()
+			dw.WriteAttribute("Cluster", url.String())
+		}
 	}
 	if (service.Spec.Template != nil) && (service.Spec.Template.Spec.ServiceAccountName != "") {
 		dw.WriteAttribute("ServiceAccount", service.Spec.Template.Spec.ServiceAccountName)
