@@ -27,8 +27,14 @@ var BuildDate string
 var GitRevision string
 
 // update this var as we add more deps
-var apiVersions = []string{
-	"serving.knative.dev/v1alpha1 (knative-serving v0.10.0)",
+var apiVersions = map[string][]string{
+	"serving": {
+		"serving.knative.dev/v1alpha1 (knative-serving v0.11.0)",
+	},
+	"eventing": {
+		"sources.eventing.knative.dev/v1alpha1 (knative-eventing v0.11.0)",
+		"eventing.knative.dev/v1alpha1 (knative-eventing v0.11.0)",
+	},
 }
 
 // NewVersionCommand implements 'kn version' command
@@ -42,8 +48,13 @@ func NewVersionCommand(p *commands.KnParams) *cobra.Command {
 			fmt.Fprintf(out, "Build Date:   %s\n", BuildDate)
 			fmt.Fprintf(out, "Git Revision: %s\n", GitRevision)
 			fmt.Fprintf(out, "Supported APIs:\n")
-			for _, api := range apiVersions {
-				fmt.Fprintf(out, "- %s\n", api)
+			fmt.Fprintf(out, "* Serving\n")
+			for _, api := range apiVersions["serving"] {
+				fmt.Fprintf(out, "  - %s\n", api)
+			}
+			fmt.Fprintf(out, "* Eventing\n")
+			for _, api := range apiVersions["eventing"] {
+				fmt.Fprintf(out, "  - %s\n", api)
 			}
 		},
 	}
