@@ -35,7 +35,11 @@ var versionOutputTemplate = `Version:      {{.Version}}
 Build Date:   {{.BuildDate}}
 Git Revision: {{.GitRevision}}
 Supported APIs:
-- serving.knative.dev/v1alpha1 (knative-serving v0.10.0)
+* Serving
+  - serving.knative.dev/v1alpha1 (knative-serving v0.11.0)
+* Eventing
+  - sources.eventing.knative.dev/v1alpha1 (knative-eventing v0.11.0)
+  - eventing.knative.dev/v1alpha1 (knative-eventing v0.11.0)
 `
 
 const (
