@@ -35,6 +35,8 @@ import (
 	"knative.dev/client/pkg/kn/commands/revision"
 	"knative.dev/client/pkg/kn/commands/route"
 	"knative.dev/client/pkg/kn/commands/service"
+	"knative.dev/client/pkg/kn/commands/source"
+	"knative.dev/client/pkg/kn/commands/trigger"
 	"knative.dev/client/pkg/kn/commands/version"
 	"knative.dev/client/pkg/kn/flags"
 )
@@ -43,7 +45,7 @@ import (
 func NewDefaultKnCommand() *cobra.Command {
 	rootCmd := NewKnCommand()
 
-	// Needed since otherwise --plugins-dir and --lookup-plugins-in-path
+	// Needed since otherwise --plugins-dir and --lookup-plugins
 	// will not be accounted for since the plugin is not a Cobra command
 	// and will not be parsed
 	pluginsDir, lookupPluginsInPath, err := extractKnPluginFlags(os.Args)
@@ -142,6 +144,8 @@ func NewKnCommand(params ...commands.KnParams) *cobra.Command {
 	rootCmd.AddCommand(route.NewRouteCommand(p))
 	rootCmd.AddCommand(completion.NewCompletionCommand(p))
 	rootCmd.AddCommand(version.NewVersionCommand(p))
+	rootCmd.AddCommand(source.NewSourceCommand(p))
+	rootCmd.AddCommand(trigger.NewTriggerCommand(p))
 
 	// Deal with empty and unknown sub command groups
 	EmptyAndUnknownSubCommands(rootCmd)
@@ -218,7 +222,7 @@ func extractKnPluginFlags(args []string) (string, bool, error) {
 	lookupPluginsInPath := false
 
 	dirFlag := "--plugins-dir"
-	pathFlag := "--lookup-plugins-in-path"
+	pathFlag := "--lookup-plugins"
 	var err error
 
 	for _, arg := range args {
@@ -235,10 +239,10 @@ func extractKnPluginFlags(args []string) (string, bool, error) {
 		}
 
 		if arg == pathFlag {
-			// just --lookup-plugins-in-path   no "="
+			// just --lookup-plugins   no "="
 			lookupPluginsInPath = true
 		} else if strings.HasPrefix(arg, pathFlag+"=") {
-			// Starts with --lookup-plugins-in-path=  so we parse value
+			// Starts with --lookup-plugins=  so we parse value
 			arg = arg[len(pathFlag)+1:]
 			if lookupPluginsInPath, err = strconv.ParseBool(arg); err != nil {
 				return "", false, fmt.Errorf("Invalid boolean value(%q) for %s flag", arg, dirFlag)
@@ -257,8 +261,8 @@ func removeKnPluginFlags(args []string) []string {
 	for _, arg := range args {
 		if arg == "--plugins-dir" ||
 			strings.HasPrefix(arg, "--plugins-dir=") ||
-			arg == "--lookup-plugins-in-path" ||
-			strings.HasPrefix(arg, "--plookup-plugins-in-path=") {
+			arg == "--lookup-plugins" ||
+			strings.HasPrefix(arg, "--lookup-plugins=") {
 			continue
 		} else {
 			remainingArgs = append(remainingArgs, arg)
